@@ -1,6 +1,8 @@
 from django.conf import settings
 from django.db.models import Q
 from rest_framework.filters import BaseFilterBackend
+from djangoldp.utils import check_client_ip
+
 
 class OwnerFilterBackend(BaseFilterBackend):
     """Adds the objects owned by the user"""
@@ -19,13 +21,23 @@ class OwnerFilterBackend(BaseFilterBackend):
 
 class PublicFilterBackend(BaseFilterBackend):
     """
-    No filter applied.
-    This class is useful for permission classes that don't filter objects, so that they can be chained with other
+    Public filter applied.
+    This class can be applied on models which bears a is_public boolean field, to filter objects that are public.
     """       
     def filter_queryset(self, request, queryset, view):
         public_field = queryset.model._meta.public_field
         return queryset.filter(**{public_field: True})
 
+class ActiveFilterBackend(BaseFilterBackend):
+    """
+    Filter which removes inactive objects from the queryset, useful for user for instance and configurable using the active_field meta
+    """
+    def filter_queryset(self, request, queryset, view):
+        if (hasattr(queryset.model._meta, 'active_field')):
+            is_active_field = queryset.model._meta.active_field
+            return queryset.filter(**{is_active_field :True})
+        return queryset
+
 class NoFilterBackend(BaseFilterBackend):
     """
     No filter applied.
@@ -133,3 +145,10 @@ class SearchByQueryParamFilterBackend(BaseFilterBackend):
             queryset = queryset.filter(_construct_search_query(search))
 
         return queryset
+
+class IPFilterBackend(BaseFilterBackend):
+    def filter_queryset(self, request, queryset, view):
+        if check_client_ip(request):
+            return queryset
+        else:
+            return queryset.none()
\ No newline at end of file
