@@ -6,8 +6,14 @@ from django.urls import path, re_path, include
 
 from djangoldp.models import LDPSource, Model
 from djangoldp.permissions import ReadOnly
-from djangoldp.views import LDPSourceViewSet, WebFingerView, InboxView
-from djangoldp.views import LDPViewSet
+from djangoldp.views.webfinger import WebFingerView
+from djangoldp.views.inbox import InboxView
+from djangoldp.views.instance_container import InstanceRootContainerView
+from djangoldp.views.webid import InstanceWebIDView
+from djangoldp.views.type_index import PublicTypeIndexView
+from djangoldp.views.ldp_viewset import LDPViewSet, LDPSourceViewSet
+from djangoldp.views.static import serve_static_content
+
 
 def __clean_path(path):
     '''ensures path is Django-friendly'''
@@ -35,7 +41,11 @@ urlpatterns = [
     re_path(r'^sources/(?P<federation>\w+)/', LDPSourceViewSet.urls(model=LDPSource, fields=['federation', 'urlid'],
                                                                     permission_classes=[ReadOnly], )),
     re_path(r'^\.well-known/webfinger/?$', WebFingerView.as_view()),
-    path('inbox/', InboxView.as_view())
+    path('inbox/', InboxView.as_view()),
+    path('', InstanceRootContainerView.as_view()),
+    path('profile', InstanceWebIDView.as_view()),
+    path('profile/publicTypeIndex', PublicTypeIndexView.as_view()),
+    re_path(r'^ssr/(?P<path>.*)$', serve_static_content, name='serve_static_content'),
 ]
 
 if settings.ENABLE_SWAGGER_DOCUMENTATION:
@@ -67,13 +77,15 @@ for model in get_all_non_abstract_subclasses(Model):
     model_path = __clean_path(model.get_container_path())
     # urls_fct will be a method which generates urls for a ViewSet (defined in LDPViewSetGenerator)
     urls_fct = getattr(model, 'view_set', LDPViewSet).urls
-    urlpatterns.append(path('' + model_path,
-        urls_fct(model=model,
-                 lookup_field=getattr(model._meta, 'lookup_field', 'pk'),
-                 permission_classes=getattr(model._meta, 'permission_classes', []),
-                 fields=getattr(model._meta, 'serializer_fields', []),
-                 nested_fields=getattr(model._meta, 'nested_fields', [])
-                 )))
+    disable_url = getattr(model._meta, 'disable_url', False)
+    if not disable_url:
+        urlpatterns.append(path('' + model_path,
+            urls_fct(model=model,
+                    lookup_field=getattr(model._meta, 'lookup_field', 'pk'),
+                    permission_classes=getattr(model._meta, 'permission_classes', []),
+                    fields=getattr(model._meta, 'serializer_fields', []),
+                    nested_fields=getattr(model._meta, 'nested_fields', [])
+                    )))
 
 # NOTE: this route will be ignored if a custom (subclass of Model) user model is used, or it is registered by a package
 # Django matches the first url it finds for a given path
